ansible-role-dci-ocp-imagesideload
==================================

An Ansible role to upload container images on each OCP nodes.
This is useful when cluster is disconnected from Internet and cannot pull images directly.

When you use the DCI Openshift agent, your `ansible.cfg` should already include the proper path to use this role (`/usr/share/dci/roles/`) and point to the right inventory (`/etc/dci-openshift-agent/hosts`).

## How to use

1) Configure the images list in `dci_images_to_side_load` variable.
2) Include the role.

```
---
- hosts: localhost
  vars:
    dci_images_to_side_load:
    - "docker.io/library/busybox:1.29"
    - "docker.io/library/nginx:1.14-alpine"
  tasks:
  - include_role:
      name: ansible-role-dci-ocp-imagesideload
```

## Variables

| Variable | Description  | Default value |
|---|---|---|
| dci_images_to_side_load | Images list to upload  | See `/usr/share/dci/roles/ansible-role-dci-ocp-imagesideload/vars/main.yml` |
| dci_ocp_imagesideload_podman_config | Install and configure podman | True  |
| dci_ocp_imagesideload_ssh_config | Generate the ssh config file to use provisionner host for ssh jump | True  |
| dci_ocp_imagesideload_ssh_user | Default user for nodes | `core` |
| dci_ocp_imagesideload_ssh_hosts | ssh config hosts regexp | `worker-* master-*` |

* All images will be uploaded to `[masters]` and `['workers']` inventory groups.
* Provisioner host used for ssh jump is `['provisioner'][0]`.


## Output

```
[dci-openshift-agent]$ ansible-playbook test.yml

PLAY [localhost] ************************************************************************************************************************************************************************************************************************

TASK [Gathering Facts] ******************************************************************************************************************************************************************************************************************
ok: [localhost]

TASK [include_role : ansible-role-dci-ocp-imagesideload] ********************************************************************************************************************************************************************************

TASK [ansible-role-dci-ocp-imagesideload : include_tasks] *******************************************************************************************************************************************************************************
included: /usr/share/dci/roles/ansible-role-dci-ocp-imagesideload/tasks/10-podman-setup.yml for localhost

TASK [ansible-role-dci-ocp-imagesideload : Install packages needed for podman] **********************************************************************************************************************************************************
ok: [localhost] => (item=podman)
ok: [localhost] => (item=slirp4netns)

TASK [ansible-role-dci-ocp-imagesideload : Check /proc/sys/user/max_user_namespaces is correct] *****************************************************************************************************************************************
ok: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Create /etc/sysctl.d/userns.conf] ************************************************************************************************************************************************************
skipping: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Run sysctl -p /etc/sysctl.d/userns.conf] *****************************************************************************************************************************************************
skipping: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Add subuid entry] ****************************************************************************************************************************************************************************
ok: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Add subgid entry] ****************************************************************************************************************************************************************************
ok: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Run podman system migrate] *******************************************************************************************************************************************************************
changed: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : include_tasks] *******************************************************************************************************************************************************************************
included: /usr/share/dci/roles/ansible-role-dci-ocp-imagesideload/tasks/20-image-side-load.yml for localhost

TASK [ansible-role-dci-ocp-imagesideload : Generate temp dir to hold the images] ********************************************************************************************************************************************************
changed: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Pull all images down to local podman registry] ***********************************************************************************************************************************************
ok: [localhost] => (item=docker.io/library/busybox:1.29)
ok: [localhost] => (item=docker.io/library/httpd:2.4.38-alpine)
ok: [localhost] => (item=docker.io/library/nginx:1.14-alpine)
ok: [localhost] => (item=gcr.io/kubernetes-e2e-test-images/mounttest:1.0)
ok: [localhost] => (item=k8s.gcr.io/pause:3.2)
ok: [localhost] => (item=us.gcr.io/k8s-artifacts-prod/e2e-test-images/agnhost:2.12)

TASK [ansible-role-dci-ocp-imagesideload : Tar all podman images] ***********************************************************************************************************************************************************************
changed: [localhost] => (item=docker.io/library/busybox:1.29)
changed: [localhost] => (item=docker.io/library/httpd:2.4.38-alpine)
changed: [localhost] => (item=docker.io/library/nginx:1.14-alpine)
changed: [localhost] => (item=gcr.io/kubernetes-e2e-test-images/mounttest:1.0)
changed: [localhost] => (item=k8s.gcr.io/pause:3.2)
changed: [localhost] => (item=us.gcr.io/k8s-artifacts-prod/e2e-test-images/agnhost:2.12)

TASK [ansible-role-dci-ocp-imagesideload : Tar all images into a big tarball] ***********************************************************************************************************************************************************
changed: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Get provisioner SSH identity] ****************************************************************************************************************************************************************
ok: [localhost -> provisionhost]

TASK [ansible-role-dci-ocp-imagesideload : Set the provisioner user fact] ***************************************************************************************************************************************************************
ok: [localhost -> provisionhost]

TASK [ansible-role-dci-ocp-imagesideload : Write SSH config to connect to the cluster nodes directly] ***********************************************************************************************************************************
ok: [localhost]

TASK [ansible-role-dci-ocp-imagesideload : Create a directory to hold all the images on cluster nodes] **********************************************************************************************************************************
changed: [localhost -> master-0] => (item=master-0)
changed: [localhost -> master-1] => (item=master-1)
changed: [localhost -> master-2] => (item=master-2)
[WARNING]: Distribution redhat 4.4 on host master-0 should use /usr/bin/python, but is using /usr/libexec/platform-python, since the discovered platform python interpreter was not present. See
https://docs.ansible.com/ansible/2.9/reference_appendices/interpreter_discovery.html for more information.
[WARNING]: Distribution redhat 4.4 on host master-1 should use /usr/bin/python, but is using /usr/libexec/platform-python, since the discovered platform python interpreter was not present. See
https://docs.ansible.com/ansible/2.9/reference_appendices/interpreter_discovery.html for more information.
[WARNING]: Distribution redhat 4.4 on host master-2 should use /usr/bin/python, but is using /usr/libexec/platform-python, since the discovered platform python interpreter was not present. See
https://docs.ansible.com/ansible/2.9/reference_appendices/interpreter_discovery.html for more information.

TASK [ansible-role-dci-ocp-imagesideload : Untar the podman images on cluster nodes] ****************************************************************************************************************************************************
changed: [localhost -> master-0] => (item=master-0)
changed: [localhost -> master-1] => (item=master-1)
changed: [localhost -> master-2] => (item=master-2)

TASK [ansible-role-dci-ocp-imagesideload : Podman load all images] **********************************************************************************************************************************************************************
changed: [localhost -> master-0] => (item=master-0)
changed: [localhost -> master-1] => (item=master-1)
changed: [localhost -> master-2] => (item=master-2)

TASK [ansible-role-dci-ocp-imagesideload : Remove image tar files from cluster nodes] ***************************************************************************************************************************************************
changed: [localhost -> master-0] => (item=master-0)
changed: [localhost -> master-1] => (item=master-1)
changed: [localhost -> master-2] => (item=master-2)

TASK [ansible-role-dci-ocp-imagesideload : Clean up temp dir] ***************************************************************************************************************************************************************************
changed: [localhost]

PLAY RECAP ******************************************************************************************************************************************************************************************************************************
localhost                  : ok=20   changed=9    unreachable=0    failed=0    skipped=2    rescued=0    ignored=0
```